Class: Fastlane::Actions::GetVersionCodeAction

Inherits:
Action
  • Object
show all
Defined in:
lib/fastlane/plugin/android_versioning/actions/get_version_code.rb

Documentation collapse

Class Method Summary collapse

Class Method Details

.authorsObject



43
44
45
# File 'lib/fastlane/plugin/android_versioning/actions/get_version_code.rb', line 43

def self.authors
  ["Manabu OHTAKE"]
end

.available_optionsObject



16
17
18
19
20
21
22
23
24
25
# File 'lib/fastlane/plugin/android_versioning/actions/get_version_code.rb', line 16

def self.available_options
  [
    FastlaneCore::ConfigItem.new(key: :app_project_dir,
                              env_name: "ANDROID_VERSIONING_APP_PROJECT_DIR",
                           description: "The path to the application source folder in the Android project (default: android/app)",
                              optional: true,
                                  type: String,
                         default_value: "android/app")
  ]
end

.descriptionObject



27
28
29
# File 'lib/fastlane/plugin/android_versioning/actions/get_version_code.rb', line 27

def self.description
  "Get the version code of your project"
end

.detailsObject



31
32
33
34
35
# File 'lib/fastlane/plugin/android_versioning/actions/get_version_code.rb', line 31

def self.details
  [
    "This action will return the current version code set on your project's build.gradle."
  ].join(' ')
end

.is_supported?(platform) ⇒ Boolean

Returns:

  • (Boolean)


47
48
49
# File 'lib/fastlane/plugin/android_versioning/actions/get_version_code.rb', line 47

def self.is_supported?(platform)
  platform == :android
end

.outputObject



37
38
39
40
41
# File 'lib/fastlane/plugin/android_versioning/actions/get_version_code.rb', line 37

def self.output
  [
    ['VERSION_CODE', 'The version code']
  ]
end

.run(params) ⇒ Object



6
7
8
9
10
11
# File 'lib/fastlane/plugin/android_versioning/actions/get_version_code.rb', line 6

def self.run(params)
  GetValueFromBuildAction.run(
    app_project_dir: params[:app_project_dir],
    key: "versionCode"
  )
end